@@ -1,15 +1,13 @@
 #ifndef __PERL_EXTRACTOR_H__
 #define __PERL_EXTRACTOR_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
 #include <proto.h>
 
+#define NEED_sv_2pvbyte
+#define NEED_newRV_noinc
 #include "ppport.h"
 
 #include <string.h>
@@ -17,6 +15,10 @@ extern "C" {
 
 #define EXTRACTOR_ExtractorList_or_null EXTRACTOR_ExtractorList
 
+#define PERL_EXTRACTOR_INVALIDED "invalidated"
+
+START_EXTERN_C
+
 SV *perl_extractor_new_sv_from_ptr (void *ptr, const char *class);
 
 void *perl_extractor_get_ptr_from_sv (SV *sv, const char *class);
@@ -29,8 +31,6 @@ void perl_extractor_invalidate_object (SV *obj);
 
 bool perl_extractor_object_is_invalid (SV *obj);
 
-#ifdef __cplusplus
-}
-#endif
+END_EXTERN_C
 
 #endif
